@@ -49,15 +49,28 @@ def generate_refline(bound_l: np.ndarray,
     # To create a valid polygon with definite enclosure of normal vectors at start and end, the polygon is extended
     # at start and end (first/last vector along bound is added again)
     both_tb = np.row_stack((
-        bound_l[0, :] - np.diff(bound_l[:2, :] * 0.4, axis=0),
+        bound_l[0, :] - np.diff(bound_l[:2, :], axis=0),
         bound_l,
-        bound_l[-1, :] + np.diff(bound_l[-2:, :] * 0.4, axis=0),
-        bound_r[-1, :] + np.diff(bound_r[-2:, :] * 0.4, axis=0),
+        bound_l[-1, :] + np.diff(bound_l[-2:, :], axis=0),
+        bound_r[-1, :] + np.diff(bound_r[-2:, :], axis=0),
         np.flipud(bound_r),
-        bound_r[0, :] - np.diff(bound_r[:2, :] * 0.4, axis=0)
+        bound_r[0, :] - np.diff(bound_r[:2, :], axis=0)
     ))
     track_polygon = Polygon(both_tb)
 
+    # if track polygon not valid, assume closure (overlapping start and end)
+    if not track_polygon.is_valid:
+        point = Point(bound_l[0, :])
+        polygon = Polygon(bound_r)
+
+        # if bound_l is inner one
+        if polygon.contains(point):
+            track_polygon = Polygon(shell=bound_r,
+                                    holes=[bound_l])
+        else:
+            track_polygon = Polygon(shell=bound_l,
+                                    holes=[bound_r])
+
     # -- iteratively smooth until track bound is left ------------------------------------------------------------------
     bool_check = inpolygon(track_polygon=track_polygon,
                            input_rl=iter_track)
